.. _trojanvision.models.nas:

nas
============

.. currentmodule:: trojanvision.models

.. autoclass:: DARTS
   :members:

.. autoclass:: ENAS
   :members:

.. autoclass:: NATSbench
   :members:

.. autoclass:: PNASNet
   :members:

.. autoclass:: ProxylessNAS
   :members:
